<?php
/**
 * Action : Convertir les logos traditionnels en logos avec rôle
 *
 * @plugin     Rôles de documents
 * @copyright  2015-2022
 * @author     tcharlss, RastaPopoulos
 * @licence    GNU/GPL
 * @package    SPIP\Roles_documents\Action
 */

// Sécurité
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Migre les documents avec un mode logo en documents avec le rôle logo équivalent
 *
 * On peut rejouer l'action plusieurs fois pour migrer progressivement.
 *
 * @return array
 *     Tableau avec la liste des documents ayant été migrés pour chaque rôle
 *     array<list logo, list logo_survol>
 */
function action_migrer_logos_modes_vers_roles_dist() {

	// On retourne le nombre de docs migrés pour chaque rôle
	$migration = [
		'logo'  => [],
		'logo_survol' => [],
	];

	// Il faut être webmestre
	// TODO : permettre d'appeler depuis spip-cli
	//$securiser_action = charger_fonction('securiser_action', 'inc');
	include_spip('inc/autoriser');
	if (autoriser('webmestre')) {

		// Les documents logos ont un mode `logoon` ou `logooff`, et sont liés aux objets avec un lien unique.
		// On garde la même nomenclature pour les rôles histoire de simplifier.
		$modes = [
			'logoon' => 'logo',
			'logooff' => 'logo_survol',
		];
		$total = 0;
		foreach ($modes as $mode => $role) {
			// Nb : on prend même ceux qui auraient éventuellement déjà un rôle logo,
			// pour être sûr de reset le mode dans ce cas.
			if ($documents = sql_allfetsel(
				'D.id_document',
				'spip_documents D INNER JOIN spip_documents_liens L ON L.id_document=D.id_document',
				'D.mode = ' . sql_quote($mode),
			)) {
				$ids_documents = array_column($documents, 'id_document');
				$ids_documents = array_map('intval', $ids_documents);
				// On ajoute le rôle logo…
				sql_updateq(
					'spip_documents_liens',
					['role' => $role],
					[sql_in('id_document', $ids_documents)]
				);
				// …et on reset le mode
				sql_updateq(
					'spip_documents',
					['mode' => 'image'], // ce sont forcément des images
					[sql_in('id_document', $ids_documents)]
				);
				// TODO : vérifier que sql_updateq s'est bien passé avant des les compter dans les migrés
				$migration[$role] = $ids_documents;
				$total += count($ids_documents);
			}
		}
		spip_log("Action migrer logos mode vers rôle : $total logos migrés", 'roles_documents' . _LOG_INFO_IMPORTANTE);

	} else {
		spip_log('Action migrer logos mode vers rôle : pas autorisé', 'roles_documents' . _LOG_ERREUR);
	}

	return $migration;
}
